@@ -3,7 +3,8 @@
 
 from ClickSQL.clickhouse.ClickHouse import ClickHouseTableNode
 from ClickSQL.clickhouse.ClickHouseExt import ClickHouseTableNodeExt
+from ClickSQL.nodes.ch_factor import BaseSingleFactorTableNode
 
-__version__ = '0.1.5.7'
+__version__ = '0.1.6'
 __author__ = 'sn0wfree'
-__all__ = ['ClickHouseTableNode', 'ClickHouseTableNodeExt']
+__all__ = ['ClickHouseTableNode', 'ClickHouseTableNodeExt','BaseSingleFactorTableNode']
